#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018–2019 Markus S. <kamikazow@opensuse.org>
# Copyright (c) 2016      Yuriy Gorodilin <yurg27@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt6%{nil}
%define name_suffix %{nil}
%if "%{flavor}" == ""
ExclusiveArch:  do_not_build
%endif
%if "%{flavor}" == "qt5"
#
# Qt5 Flavor
#
  %define pkg_name QGnomePlatform-qt5
  %define qt5 1
  %define qt_min_version 5.15.2
  %define _qt_plugindir %{_libqt5_plugindir}
  %define name_suffix -qt5
%endif
%if "%{flavor}" == "qt6"
#
# Qt6 Flavor
#
  %define pkg_name QGnomePlatform-qt6
  %define qt6 1
  %define qt_min_version 6.2.0
  %define _qt_plugindir %{_qt6_pluginsdir}
  %define name_suffix -qt6
%endif

%define adwaitaqt_version 1.4.2

Name:           QGnomePlatform%{?name_suffix}
Version:        0.9.1
Release:        2.14
Summary:        A better Qt application inclusion under GNOME
#
# Most code is LGPL-2.1 or any later version but qgtk3dialoghelpers files,
# forked from Qt 5, let's us choose beteween LGPL-3.0 and GPL-2.0 or even
# GPL-3.0 or still any later version approved by the KDE Free Qt Foundation.
# So we're better off using LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only on
# behalf of qgtk3dialoghelpers' source code rather the using *-or-later and
# risk getting screwed over by KDE Free Qt Foundation someday.
#
# This is what the license tag should look like:
#   LGPL-2.1-or-later AND (LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-only))
#
# But since we do not have support for such nested logic let us use:
#   LGPL-2.1-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only)
#
# NOTE: Keep an eye on it so that the bots don't mess up the logic, ordey is
#       important here.
#       You may have to append --noservice to 'osc build'/'osc checkin'.
#
License:        (GPL-2.0-only OR LGPL-3.0-only OR GPL-3.0-only) AND LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://github.com/FedoraQt/QGnomePlatform/
Source:         %{url}/archive/%{version}.tar.gz#/QGnomePlatform-%{version}.tar.gz
Patch0:         fix-XSetTransientForHint.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
# QGnomePlatform relies on glib's pkgconfig file to find gsettings files
BuildRequires:  gsettings-desktop-schemas
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
%if 0%{?qt5}
#
# Qt5 Buildtime Dependencies
#
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qtwayland-private-headers-devel
BuildRequires:  cmake(AdwaitaQt) >= %{adwaitaqt_version}
BuildRequires:  cmake(Qt5Core) >= %{qt_min_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt_min_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt_min_version}
BuildRequires:  cmake(Qt5QuickControls2) >= %{qt_min_version}
BuildRequires:  cmake(Qt5ThemeSupport)
BuildRequires:  cmake(Qt5WaylandClient) >= %{qt_min_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt_min_version}
BuildRequires:  cmake(Qt5XkbCommonSupport)
Obsoletes:      QGnomePlatform =< 0.8.4
Provides:       QGnomePlatform = %{version}
%endif
%if 0%{?qt6}
#
# Qt6 Buildtime Dependencies
#
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-wayland-private-devel
# Use cmake() instead of pkgconfig() to make Leap 15.4's life easier.
BuildRequires:  cmake(AdwaitaQt6) >= %{adwaitaqt_version}
BuildRequires:  cmake(Qt6Core) >= %{qt_min_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt_min_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt_min_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt_min_version}
%endif
#
# Runtime Dependencies
#
Requires:       adwaita-%{flavor}
# Make all flavors depend on the same color schemes subpackage. (see below)
Requires:       QGnomePlatform-colorschemes

%description
QGnomePlatform is a Qt Platform Theme designed to use as many of the GNOME
settings as possible in unmodified Qt applications. It allows Qt applications
to fit into the environment as well as possible.

#
# All flavors of QGnomePlaform depend on the same color scheme files.
# In order to avoid duplicatate production of the same package,
# we only produce the color schemes package when building the qt5 flavor.
# When removing the Qt5 flavor from this package, please ensure that the
# color schemes package is produced in another flavor's build instead.
#

# Only produce the color schemes package when building the qt5 flavor. (see above)
%if 0%{?qt5}
%package -n QGnomePlatform-colorschemes
Summary:        Color schemes for QGnomePlatform
Group:          System/Libraries
BuildArch:      noarch

%description -n QGnomePlatform-colorschemes
QGnomePlatform is a Qt Platform Theme designed to use as many of the GNOME
settings as possible in unmodified Qt applications. It allows Qt applications
to fit into the environment as well as possible.
%endif

%prep
%autosetup -p1 -n QGnomePlatform-%{version}

%build
%if 0%{?qt6}
%cmake_qt6                 \
%else
%cmake                     \
%endif
    %{?qt5:-D USE_QT6=OFF} \
    %{?qt6:-D USE_QT6=ON}  \
    %{nil}

%if 0%{?qt6}
%qt6_build
%else
%cmake_build
%endif

%install
%if 0%{?qt6}
%{qt6_install}
%else
%cmake_install
%endif
# Only produce the color schemes package when building the qt5 flavor. (see above)
%if ! 0%{?qt5}
rm -r %{buildroot}%{_datadir}/color-schemes
%endif

%files
%doc README.md
%license LICENSE
# Qt6 SONAME is libqgnomeplatform6.so so expand a "6" when appropriate.
%{_libdir}/libqgnomeplatform%{?qt6:6}.so
%dir %{_qt_plugindir}
%dir %{_qt_plugindir}/platformthemes
%{_qt_plugindir}/platformthemes/libqgnomeplatformtheme.so
%{_qt_plugindir}/wayland-decoration-client/libqgnomeplatformdecoration.so

# Only produce the color schemes package when building the qt5 flavor. (see above)
%if 0%{?qt5}
%files -n QGnomePlatform-colorschemes
%dir %{_datadir}/color-schemes
%{_datadir}/color-schemes/Adwaita.colors
%{_datadir}/color-schemes/AdwaitaDark.colors
%{_datadir}/color-schemes/AdwaitaHighcontrast.colors
%{_datadir}/color-schemes/AdwaitaHighcontrastInverse.colors
%endif

%changelog
* Wed Sep 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop (libQt5Gui5 and gnome-session) and
  (libQt6Gui6 and gnome-session) Supplements: No longer install
  automatically when the above conditions are met. Upstream have
  stopped maintenance of these packages, and are considered
  obsolete.
* Thu May 11 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.9.1:
  + Changes:
  - Thinner border between window and decorations
  - Added support for KColorScheme using Adwaita-like color
    schemes
  - Added integration for QtQuick Controls2 applications
  - Added support for color-scheme in GSettings backend
  - Implemented reasonable icon fallback - depends on Qt change
    476542
  - Qt6: implemented support for QPlatformTheme::MouseCursorSize
    and QPlatformTheme::MouseCursorTheme
  + Fixes:
  - Do not crash when GSettings shema is not found
  - Respect QT_STYLE_OVERRIDE env variable
  - Fixed titlebar dimming on Wayland
  - Fixed regression in rendering titlebar on vanilla Qt
- Drop 0001-fix-qt-6.5-compilation.patch as it is included in
  version 0.9.1
- Adjust fix-XSetTransientForHint.patch for version 0.9.1
- Split QGnomePlatform's new color schemes into a new package
  called "QGnomePlatform-colorschemes"
* Thu Apr  6 2023 Simon Vogl <simon.vogl@gmx.net>
- Add 0001-fix-qt-6.5-compilation.patch to fix a compilation
  error with qt 6.5
* Thu Mar  2 2023 Antonio Larrosa <alarrosa@suse.com>
- Don't use %%elif which is not supported in SLE/Leap
- Use qt6 macros when building the qt6 flavor so the correct
  compiler is used to build the package in SLE/Leap
- Add patch to fix an undefined reference to XSetTransientForHint
  in SLE/Leap:
  * fix-XSetTransientForHint.patch
* Tue Sep 27 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 0.9.0:
  + Changes:
  - QGnomePlatform has been now internally split into two
    providers for configuration, where only one is used at a time
    (not mixed together as before). We can even switch between
    providers on runtime, e.g. when xdg-desktop-portal is started
    later.
  - QGnomePlatform can now switch between dark/light themes on
    runtime (requires Adwaita-qt 1.4.2).
  - Implements QPlatformTheme::Appearance() for Qt6.
  - Added support for window menu into client-side decorations.
  - Added support for native system try icon using QGnomeTheme
    for Qt6.
  - Added support for GNOME 42 theme switching (using Settings
    portal).
  + Fixes:
  - FileChooser portal: send window id in hex and only for
    xwayland apps (backport from Qt).
  - Ensure gtk uses the same windowing system as Qt (backport
    from Qt).
  - Fixes decoration size when QT_SCALE_FACTOR is set.
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add Obsoletes/Provides QGnomePlatform to ease the switch-over.
* Mon Sep  5 2022 Luciano Santos <luc14n0@opensuse.org>
- Add multibuild facility to provide both Qt5 and Qt6 flavors. This
  is needed to hook up the right Qt base from adwaita-qt and apply
  the configurations needed to change the styling of the window of
  Qt apps under GNOME (boo#1202526).
- Add respective Qt6 build requirements and make use of
  conditionals to produce a multibuild package based on flavors.
- Replace build requirements to match explicitly what CMakeLists
  is looking for: libQt5PlatformSupport-private-headers-devel ->
  cmake(Qt5XkbCommonSupport), and libQt5Core-private-headers-devel
  - > cmake(Qt5Core).
- Drop unneeded build requirements that are not used nor looked for
  by CMake: pkgconfig(Qt5X11Extras), libqt5-qtwayland-devel (CMake
  only looks for Qt5WaylandClient and WaylandClientPrivate),
  pkgconfig(x11), and pkgconfig(gtk+-x11-3.0).
- Add explicit pkgconfig(glib-2.0) build requirement looked for by
  CMake but undeclared in the spec file. It was already being
  pulled by another package though.
- Switch all pkgconfig(*) modules by cmake(*) ones. Leap 15.4 has a
  hard time finding pkgconfig(*) modules for adwaita-qt6, so switch
  all qt5-dependecies too to keep them consistent.
- Update License tag from "GPL-2.0-or-later OR LGPL-3.0-only" to
  "LGPL-2.1-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR
  GPL-3.0-only)". Basically all the source code is LGPL-2.1 or any
  later version, but the qgtk3dialoghelpers cpp/header files can be
  either LGPL-3.0 or choose between GPL-2.0 and GPL-3.0 and later
  versions approved by the KDE Free Qt Foundation.
* Wed Feb 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.4:
  + Set XCURSOR_THEME env variable on Wayland
  + Use C++14 to build QGnomePlatform for a KDE/Qt 5.15 change
- Changes from version 0.8.3:
  + Restored QDBusTrayIcon support for Qt5 version
- Changes from version 0.8.2:
  + Removed support for QDBusTrayIcon causing issue with undefined
    reference as Qt doesn't export required symbols
- Changes from version 0.8.1:
  + Bumped dependency on Adwaita-qt 1.4.1 and Qt 5.15.2
  + Support for Qt6 build with CMake option -DUSE_QT6=true
  + Support HighContrast variants of Adwaita-qt
- Drop baselibs.conf, stop supporting 32bit libs on x86_64.
* Tue Jul 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing gsettings-desktop-schemas build requirement.
* Sat Jul  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.0
  + Updated dependency on Adwaita-qt 1.3.0
  + QGnomePlatform now uses CMake instead of QMake
  + Window decoration buttons now have hover effect
  + Window decoration buttons are now rendered using Adwaita library
  + Window decoration border improvements
- Drop fix-qt5-x11-config.patch
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.7.1:
  + Fixed wrong color palette with Qt 5.15
  + Fixed issue when font configuration was not parsed properly
  + Use xdg-desktop-portal for opening files
  + Prioritize Adwaita dark variant for all themes
    containing "-dark" suffix
  + Use FileChooser portal only when possible
  + Take QT_STYLE_OVERRIDE into account when considering dark variant
  + Fixed memory leaks
- Add  fix-qt5-x11-config.patch, linking fails because of missing
  x11 link time dependency of gtk3
- Drop QGnomePlatform-qt-5.15.patch: Upstream fixed
* Tue Jun  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.6.1:
  + Preview support in file dialog.
  + Prioritize Adwaita-dark theme for all themes ending with
    "-dark" suffix.
  + Use Qt's default palette.
- Add QGnomePlatform-qt-5.15.patch: Fix build with Qt 5.15.
* Fri Jan 17 2020 Stasiek Michalski <stasiek@michalski.cc>
- Install automatically with gnome-session and libqt5 base
* Sun Nov 24 2019 Markus S <kamikazow@opensuse.org>
- Update to 0.6
  * Window decorations on Wayland
  * Qt 5.13 compatibility
  * Modified description to match upstream
* Thu Mar 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Tweak spec, use modern macros where possible.
* Wed Mar 13 2019 Markus S <kamikazow@opensuse.org>
- Upstream URL has changed
* Wed Mar 13 2019 Markus S <kamikazow@opensuse.org>
- Update to version 0.5
  * support for Kvantum themes
  * support for QDBusTrayIcon
  * fixed crash when opening native gtk dialog without parent
  * Cinnamon settings Support
  * Flatpak Settings Portal support
  * Font scaling bug fixes
* Fri Feb 23 2018 Markus S <kamikazow@opensuse.org>
- Small licensing metadata fixes
* Thu Feb 22 2018 fcrozat@suse.com
- Initial package by Yuriy Gorodilin.
- Remove BuildRequires on qt4, it is not needed.
- Add Requires on adwaita-qt5.
